Command line interface
======================

Installing the FreeDiscovery Engine is controlled with the ``freediscovery`` CLI command. It can be used to start the server and to manage trained models.

.. autoprogram:: freediscovery.__main__:main(return_parser=True)
   :prog: freediscovery
